@@ -89,30 +89,3 @@ sub _get_cache_dir {
 }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Giovanni::Plugins::Git
-
-=head1 VERSION
-
-version 1.12
-
-=head1 AUTHOR
-
-Lenz Gschwendtner <mail@norbu09.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by ideegeo Group Limited.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
